@@ -42,7 +42,7 @@ hildon_file_system_voldev_is_visible (HildonFileSystemSpecialLocation *location)
 
 static void
 hildon_file_system_voldev_volumes_changed (HildonFileSystemSpecialLocation
-					   *location, GtkFileSystem *fs);
+                                           *location, GtkFileSystem *fs);
 
 G_DEFINE_TYPE (HildonFileSystemVoldev,
                hildon_file_system_voldev,
@@ -76,14 +76,14 @@ static void
 hildon_file_system_voldev_finalize (GObject *obj)
 {
     HildonFileSystemVoldev *voldev;
-    
+
     voldev = HILDON_FILE_SYSTEM_VOLDEV (obj);
 
     if (voldev->volume)
       gnome_vfs_volume_unref (voldev->volume);
     if (voldev->drive)
       gnome_vfs_drive_unref (voldev->drive);
-    
+
     G_OBJECT_CLASS (hildon_file_system_voldev_parent_class)->finalize (obj);
 }
 
@@ -97,7 +97,7 @@ hildon_file_system_voldev_is_visible (HildonFileSystemSpecialLocation *location)
     visible = gnome_vfs_volume_is_mounted (voldev->volume);
   else if (voldev->drive)
     visible = (gnome_vfs_drive_is_connected (voldev->drive)
-	       && !gnome_vfs_drive_is_mounted (voldev->drive));
+               && !gnome_vfs_drive_is_mounted (voldev->drive));
 
   return visible;
 }
@@ -117,10 +117,10 @@ find_drive (const char *device)
       GnomeVFSDrive *dr = d->data;
 
       if (!strcmp (device, gnome_vfs_drive_get_device_path (dr)))
-	{
-	  drive = dr;
-	  break;
-	}
+        {
+          drive = dr;
+          break;
+        }
     }
   g_list_free (drives);
 
@@ -145,10 +145,10 @@ find_volume (const char *uri)
       GnomeVFSVolume *vo = v->data;
 
       if (!strcmp (uri, gnome_vfs_volume_get_activation_uri (vo)))
-	{
-	  volume = vo;
-	  break;
-	}
+        {
+          volume = vo;
+          break;
+        }
     }
   g_list_free (volumes);
 
@@ -160,7 +160,7 @@ find_volume (const char *uri)
 
 static void
 hildon_file_system_voldev_volumes_changed (HildonFileSystemSpecialLocation
-					   *location, GtkFileSystem *fs)
+                                           *location, GtkFileSystem *fs)
 {
   HildonFileSystemVoldev *voldev = HILDON_FILE_SYSTEM_VOLDEV (location);
 
@@ -177,7 +177,7 @@ hildon_file_system_voldev_volumes_changed (HildonFileSystemSpecialLocation
   if (voldev->volume)
     {
       location->fixed_title =
-	gnome_vfs_volume_get_display_name (voldev->volume);
+        gnome_vfs_volume_get_display_name (voldev->volume);
       location->fixed_icon = gnome_vfs_volume_get_icon (voldev->volume);
     }
   else if (voldev->drive)
@@ -185,9 +185,21 @@ hildon_file_system_voldev_volumes_changed (HildonFileSystemSpecialLocation
       location->fixed_title = gnome_vfs_drive_get_display_name (voldev->drive);
       location->fixed_icon = gnome_vfs_drive_get_icon (voldev->drive);
     }
-  
-  /* XXX */
-  location->fixed_icon = "qgn_list_filesys_mmc_root";
+
+  /* XXX - GnomeVFS should provide the right icons and display names.
+   */
+
+  if (strcmp (location->fixed_icon, "gnome-dev-removable-usb") == 0
+      || strcmp (location->fixed_icon, "gnome-dev-harddisk-usb") == 0)
+    location->fixed_icon = "qgn_list_filesys_removable_storage";
+  else if (strcmp (location->fixed_icon, "gnome-dev-removable") == 0
+	   || strcmp (location->fixed_icon, "gnome-dev-media-sdmmc") == 0)
+    {
+      if (g_str_has_prefix (location->basepath, "file:///media/mmc2"))
+	location->fixed_icon = "qgn_list_gene_internal_memory_card";
+      else
+      	location->fixed_icon = "qgn_list_gene_removable_memory_card";
+    }
 
   g_signal_emit_by_name (location, "changed");
 }
